PyBaccarat: pybaccarat.baccarat.Ties Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | List of all members
pybaccarat.baccarat.Ties Class Reference

This class tracks tie results. More...

Inheritance diagram for pybaccarat.baccarat.Ties:

## Public Member Functions
def | __init__ (self)
| TBD.
def | mark (self, winner)
| Record the winning hand from a game. More...
def | __str__ (self)
| Print the current status of the tie tracker.
def | __init__ (self)
| TBD.
def | mark (self, winner)
| Record the winning hand from a game. More...
def | __str__ (self)
| Print the current status of the tie tracker.

## Detailed Description

This class tracks tie results.

## Member Function Documentation

## ◆ mark() [1/2]

def pybaccarat.baccarat.Ties.mark | ( |  | self,
|  |  | winner
| ) |  |

Record the winning hand from a game.

Parameters

  winner | char 'B' or 'P' or 'T'

## ◆ mark() [2/2]

def pybaccarat.baccarat.Ties.mark | ( |  | self,
|  |  | winner
| ) |  |

Record the winning hand from a game.

Parameters

  winner | char 'B' or 'P' or 'T'

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccarat.py